/*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*\

  System Core TypeScript Library

  Copyright (c) TypeScriptLibs and Contributors

  Licensed under the MIT License; you may not use this file except in
  compliance with the License. You may obtain a copy of the MIT License at
  https://typescriptlibs.org/LICENSE.txt

\*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*/
import ICollection from './ICollection';
import IDictionary from './IDictionary';
import IEnumerator from './IEnumerator';
import IEquatable from '../../IEquatable';
import KeyValuePair from './KeyValuePair';
import Object from '../../Object';
import Type from '../../Type';
/**
 * A generic representation of a dictionary.
 * @extends Object
 * @implements ICollection, IDictionary
 */
export declare class Dictionary<TKey extends IEquatable<TKey>, TValue extends IEquatable<TValue>> extends Object implements ICollection<KeyValuePair<TKey, TValue>>, IDictionary<TKey, TValue> {
    /**
     * Initializes a new instance of a the dictionary.
     */
    constructor();
    private _pairs;
    /**
     * The number of keys in this dictionary.
     */
    readonly count: number;
    /**
     * Indicates whether this dictionary is read-only.
     */
    readonly isReadOnly: boolean;
    /**
     * The keys of the pairs.
     */
    readonly keys: ICollection<TKey>;
    /**
     * The underlying dictionary with stringified keys and key value pairs.
     */
    readonly item: {
        [keyString: string]: KeyValuePair<TKey, TValue>;
    };
    /**
     * The values of the pairs.
     */
    readonly values: ICollection<TValue>;
    /**
     * Adds a new pair to the dictionary.
     * @param {KeyValuePair} pair The new pair for the dictionary.
     */
    add(pair: KeyValuePair<TKey, TValue>): void;
    /**
     * Removes all pairs from the dictionary.
     */
    clear(): void;
    /**
     * Tests whether a pair is part of the dictionary.
     * @param {KeyValuePair} pair The pair to test.
     * @return {boolean} Returns true if the pair is part of the dictionary, otherwise false.
     */
    contains(pair: KeyValuePair<TKey, TValue>): boolean;
    /**
     * Returns an enumerator that iterates through the dictionary of key value pairs.
     * @return {IEnumerator} Returns the enumerator for the dictionary.
     */
    getEnumerator(): IEnumerator<KeyValuePair<TKey, TValue>>;
    /**
     * Returns the type of the dictionary for further reflection.
     * @return {System.Type} Returns the type of this dictionary.
     */
    getType(): Type;
    /**
     * Removes a pair from the dictionary.
     * @param {KeyValuePair} pair The pair to remove.
     */
    remove(pair: KeyValuePair<TKey, TValue>): void;
}
export default Dictionary;
