/*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*\

  System Core TypeScript Library

  Copyright (c) TypeScriptLibs and Contributors

  Licensed under the MIT License; you may not use this file except in
  compliance with the License. You may obtain a copy of the MIT License at
  https://typescriptlibs.org/LICENSE.txt

\*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*/
import IEnumerable from './IEnumerable';
/**
 * Represents a generic collection of elements.
 */
export interface ICollection<T> extends IEnumerable<T> {
    /**
     * The number of elements in this collection.
     */
    count: number;
    /**
     * Indicates whether this collection is read-only.
     */
    isReadOnly: boolean;
    /**
     * Adds a new element to the collection.
     */
    add(element: T): void;
    /**
     * Removes all elements from the collection.
     */
    clear(): void;
    /**
     * Tests whether an element is part of the collection.
     */
    contains(element: T): boolean;
    /**
     * Removes an element from the collection.
     */
    remove(element: T): void;
}
export default ICollection;
