/*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*\

  System Core TypeScript Library

  Copyright (c) TypeScriptLibs and Contributors

  Licensed under the MIT License; you may not use this file except in
  compliance with the License. You may obtain a copy of the MIT License at
  https://typescriptlibs.org/LICENSE.txt

\*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*/
import IEquatable from '../../IEquatable';
import Object from '../../Object';
import Type from '../../Type';
/**
 * This class provides a structure for a key/value pair.
 */
export declare class KeyValuePair<TKey extends IEquatable<TKey>, TValue extends IEquatable<TValue>> extends Object implements IEquatable<KeyValuePair<TKey, TValue>> {
    /**
     * Create a new instance with the given key/value pair.
     * @param {Object} key The key of the pair.
     * @param {Object} value The value of the pair.
     */
    constructor(key: TKey, value: TValue);
    private _key;
    private _value;
    /**
     * The key of this pair.
     */
    readonly key: TKey;
    /**
     * The value of this pair.
     */
    readonly value: TValue;
    /**
     * Compares this pair with an other pair for equality.
     * @param {KeyValuePair|null} other The pair to compare with.
     * @return {boolean} Returns true, if the pairs are equal, otherwise false.
     */
    equals(other: (KeyValuePair<TKey, TValue> | null)): boolean;
    /**
     * Returns the type of this pair for further reflection.
     * @return {System.Type} Returns the type of this pair.
     */
    getType(): Type;
}
export default KeyValuePair;
