/*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*\

  System Core TypeScript Library

  Copyright (c) TypeScriptLibs and Contributors

  Licensed under the MIT License; you may not use this file except in
  compliance with the License. You may obtain a copy of the MIT License at
  https://typescriptlibs.org/LICENSE.txt

\*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*/
import IEquatable from './IEquatable';
import Object from './Object';
import Type from './Type';
/**
 * This is the base class for enumerations.
 * @extends System.Object
 * @implements System.IEquatable
 */
export declare abstract class Enum extends Object implements IEquatable<Enum> {
    /**
     * Creates a new member for enumerations.
     * @param {string} name The name of the member in the enumeration.
     * @param {boolean|number|string} value The value of the member in the enumeration.
     */
    constructor(name: string, value?: (boolean | number | string));
    private _name;
    private _value;
    /**
     * Compares this object with an other object for equality.
     * @param {System.Enum|System.Object|null} other The object to compare with.
     * @return {boolean} Returns true, if the objects are equal, otherwise false.
     */
    equals(other: (Enum | Object | null)): boolean;
    /**
     * Returns the type of an enum for further reflection. Must be
     * overwritten by every enum.
     * @return {System.Type} Returns the type of this enum.
     */
    abstract getType(): Type;
}
export default Enum;
