/*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*\

  System Core TypeScript Library

  Copyright (c) TypeScriptLibs and Contributors

  Licensed under the MIT License; you may not use this file except in
  compliance with the License. You may obtain a copy of the MIT License at
  https://typescriptlibs.org/LICENSE.txt

\*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*/
import EventArgs from './EventArgs';
import EventHandler from './EventHandler';
import Object from './Object';
import Type from './Type';
/**
 * This is the classic event system and is used by some core classes.
 * @extends Object
 */
export declare class Event<TEventArgs extends EventArgs = EventArgs> extends Object {
    /**
     * Initializes a new event system.
     */
    constructor();
    private _eventHandlers;
    /**
     * Adds an event handler to the event system and returns the handler with
     * his associated unique ID.
     * @param {EventHandler} eventHandler The event handler to add.
     * @returns {EventHandler} The EventHandler with his unique ID.
     */
    add(eventHandler: EventHandler<TEventArgs>): EventHandler<TEventArgs>;
    /**
     * Returns the type of the event system for further reflection.
     * @return {System.Type} The type of this event system.
     */
    getType(): Type;
    /**
     * Raises the event and calls all registered event handlers with the given arguments.
     * @param {Object} sender The sender of the event.
     * @param {TEventArgs} e The arguments of the event.
     */
    raise(sender: Object, e: TEventArgs): void;
    /**
     * Removes an event handler from the event system.
     * @param {EventHandler} eventHandler The event handler to remove.
     */
    remove(eventHandler: EventHandler<TEventArgs>): void;
}
export default Event;
