/*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*\

  System Core TypeScript Library

  Copyright (c) TypeScriptLibs and Contributors

  Licensed under the MIT License; you may not use this file except in
  compliance with the License. You may obtain a copy of the MIT License at
  https://typescriptlibs.org/LICENSE.txt

\*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*/
import IConvertible from './IConvertible';
import IEquatable from './IEquatable';
import Object from './Object';
import Type from './Type';
import TypeCode from './TypeCode';
/**
 * The string class represent a text string and provides functions for
 * analysation and manipulation.
 * @extends System.Object
 * @implements IConvertible, IEquatable<System.String>
 */
export declare class String extends Object implements IConvertible, IEquatable<String> {
    /**
     * Represents an empty string.
     */
    static readonly EMPTY: String;
    /**
     * Creates a new text string.
     * @param value The primitive value of the new text string.
     */
    constructor(value?: string);
    private _hashCode;
    private _value;
    /**
     * Determines whether the ending of this text string matches the provided string value.
     * @param {string} value The provided string to compare with this text string.
     * @returns {boolean} True if this text string ends with the provided value.
     */
    endsWith(value: string): boolean;
    /**
     * Compares this object with an other object for equality.
     * @param {System.String|System.Object|null} other The object to compare with.
     * @return {boolean} Returns true, if the objects are equal, otherwise false.
     */
    equals(other: (String | Object | null)): boolean;
    /**
     * Generates a unique code for this string.
     * @return {number} Returns the unique code for this string.
     */
    getHashCode(): number;
    /**
     * Returns the type of the string for further reflection.
     * @return {System.Type} Returns the type of this string.
     */
    getType(): Type;
    /**
     * Return the type code for the string class.
     * @returns {System.TypeCode} The type code for the string class.
     */
    getTypeCode(): TypeCode;
    /**
     * Determines whether the beginning of this text string matches the provided string value.
     * @param {string} value The provided string to compare with this text string.
     * @returns {boolean} True if this text string begins with the provided value.
     */
    startsWith(value: string): boolean;
    /**
     * Returns this object without any conversion.
     * @return {System.String} This object without any conversion.
     */
    toSystemString(): String;
    /**
     * Returns the primitive value for this string.
     * @return {string} Return the primitive value of this string.
     */
    valueOf(): string;
}
export default String;
