/*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*\

  System Core TypeScript Library

  Copyright (c) TypeScriptLibs and Contributors

  Licensed under the MIT License; you may not use this file except in
  compliance with the License. You may obtain a copy of the MIT License at
  https://typescriptlibs.org/LICENSE.txt

\*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*/
import IEquatable from './IEquatable';
import Object from './Object';
/**
 * The type class of an object provides information for further reflection.
 * @extends System.Object
 * @implements IEquatable<System.Type>
 */
export declare class Type extends Object implements IEquatable<Type> {
    /**
     * Load class and returns its type.
     * @param {string} name The name of the class.
     * @param {string} namespace The namespace to the class file.
     * @returns {System.Type|null}
     */
    static getType(name: string, namespace: string): (Type | null);
    /**
     * Creates the class type of a given object.
     * @param {System.Object} obj An instance object of the class.
     * @param {string} namespace The namespace of the class.
     */
    constructor(obj: Object, namespace: string);
    private _directoryPath;
    private _hashCode;
    private _name;
    private _namespace;
    private _numberOfArguments;
    /**
     * The directory path to the class file.
     */
    readonly directoryPath: (string | null);
    /**
     * The full class name.
     */
    readonly fullName: string;
    /**
     * The namespace of this class.
     */
    readonly namespace: (string | null);
    /**
     * Compares this object type with another object type.
     * @param {System.Type|System.Object|null} other The other object or type to compare with.
     * @returns {boolean} Returns true, if the objects are equal, otherwise false.
     */
    equals(other: (Type | Object | null)): boolean;
    /**
     * Generates a unique code for this type.
     * @return {number} Returns the unique code for this type.
     */
    getHashCode(): number;
    /**
     * Returns the full name of the representing class.
     * @return {string} Returns the full class name.
     */
    toString(): string;
    /**
     * Returns itself for further reflection.
     * @returns {Type} Returns this type.
     */
    getType(): Type;
}
export default Type;
